@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: mono-traversable
 version: 0.10.1.1
-id: mono-traversable-0.10.1.1-7ac62162d55f8d714083ba886bfb5efd
-key: monot_2PxlfpjOgIc4vO19U1UddJ
+id: mono-traversable-0.10.1.1-d8076f94d0f4a1c39fe9d5feae3b294a
+key: monot_LcP9JJjSIuW1yHidunHmAC
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/snoyberg/mono-traversable
@@ -21,24 +21,24 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/mono-traversable-0.10.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/mono-traversable-0.10.1.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/mono-traversable-0.10.1.1
-hs-libraries: HSmono-traversable-0.10.1.1-2PxlfpjOgIc4vO19U1UddJ
+hs-libraries: HSmono-traversable-0.10.1.1-LcP9JJjSIuW1yHidunHmAC
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    comonad-5-a91321d086a2de4a04a44d60c347669e
+    comonad-5-e98e7adc8875accf64a86529d9aeae51
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     dlist-0.7.1.2-60b8202d1ee1445c0a53e803464ea95b
-    dlist-instances-0.1-235f738d61a8b9c3c8305b99c3fa9cbe
-    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
+    dlist-instances-0.1-cab5ba8dec85a2fc711ad48fe3f632f9
+    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
+    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
     split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
     vector-algorithms-0.7.0.1-7844ad1f07fd0916dddd070104841af1
-    vector-instances-3.3.1-defbdcf4d1ffa7a1e6ebdf8243634c01
+    vector-instances-3.3.1-02e9d5a5e0f0cb8c3532624a3303c400
 haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
 haddock-html: /usr/share/doc/haskell-mono-traversable/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
